wsgisubdomain
=============

wsgisubdomain is a WSGI application dispatcher. A WSGI application is fetched based on a request’s target subdomain, creating one if needed.

wsgisubdomain supports Python 2.6, 2.7, 3.2, 3.3 and PyPy.

The code in this module is adapted from:
http://flask.pocoo.org/docs/patterns/appdispatch/#dispatch-by-subdomain

[Read the complete docs](https://pystmark.readthedocs.org)

[![Build Status](https://travis-ci.org/xsleonard/pystmark.png)](https://travis-ci.org/xsleonard/pystmark)
